summaryrefslogtreecommitdiff
path: root/xmake/core/project/policy.lua
diff options
context:
space:
mode:
authorruki <[email protected]>2022-09-08 00:51:05 +0800
committerruki <[email protected]>2022-09-08 00:51:05 +0800
commit72384b987dc3565a1f37f7e5728db7dd5846394d (patch)
tree330a2f2926e91903f817edf065017adcc619a09b /xmake/core/project/policy.lua
parent96d2662955aae226e3ff5705ed5f7e2ac98da6d9 (diff)
add package.strict_compatibility
Diffstat (limited to 'xmake/core/project/policy.lua')
-rw-r--r--xmake/core/project/policy.lua10
1 files changed, 7 insertions, 3 deletions
diff --git a/xmake/core/project/policy.lua b/xmake/core/project/policy.lua
index b746f6853..c58b60cbb 100644
--- a/xmake/core/project/policy.lua
+++ b/xmake/core/project/policy.lua
@@ -71,10 +71,14 @@ function policy.policies()
["package.include_external_headers"] = {description = "Use includes as external headers.", type = "boolean"},
-- inherit the configs from the external command arguments, e.g. toolchains, `xmake f --toolchain=`
["package.inherit_external_configs"] = {description = "Inherit the configs from the external command arguments.", default = true, type = "boolean"},
- -- set strict compatibility for package dependencies
- -- if true, then any updates to linked dependencies, such as buildhash changes due to version changes,
+ -- set strict compatibility for package and it's all child packages
+ -- if true, then any updates to this package, such as buildhash changes due to version changes,
+ -- will force all installed child packages to be recompiled and installed, @see https://github.com/xmake-io/xmake/issues/2719
+ ["package.strict_compatibility"] = {description = "Set strict compatibility for package and it's all child packages.", type = "boolean"},
+ -- set strict compatibility for package and it's all library dependencies
+ -- if true, then any updates to library dependencies, such as buildhash changes due to version changes,
-- will force the installed packages to be recompiled and installed. @see https://github.com/xmake-io/xmake/issues/2719
- ["package.librarydeps.strict_compatibility"] = {description = "Set strict compatibility for package dependencies.", type = "boolean"},
+ ["package.librarydeps.strict_compatibility"] = {description = "Set strict compatibility for package and it's all library dependencies.", type = "boolean"}
}
policy._POLICIES = policies
end